@@ -79,7 +79,7 @@ class PushoverNotifications(Plugin):
             return
 
         # https://github.com/getsentry/sentry/blob/master/src/sentry/models.py#L353
-        if event.level <= int(self.get_option('severity', event.project)):
+        if event.level < int(self.get_option('severity', event.project)):
             return
 
         title = '%s: %s' % (event.get_level_display().upper(), event.error().split('\n')[0])
